@@ -11,7 +11,7 @@ from jsii.python import classproperty
 
 import aws_cdk.aws_iam
 import aws_cdk.core
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-kms", "1.8.0", __name__, "aws-kms@1.8.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-kms", "1.9.0", __name__, "aws-kms@1.9.0.jsii.tgz")
 @jsii.data_type(jsii_type="@aws-cdk/aws-kms.AliasAttributes", jsii_struct_bases=[], name_mapping={'alias_name': 'aliasName', 'alias_target_key': 'aliasTargetKey'})
 class AliasAttributes():
     def __init__(self, *, alias_name: str, alias_target_key: "IKey"):
@@ -42,18 +42,20 @@ class AliasAttributes():
         return 'AliasAttributes(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
-@jsii.data_type(jsii_type="@aws-cdk/aws-kms.AliasProps", jsii_struct_bases=[], name_mapping={'alias_name': 'aliasName', 'target_key': 'targetKey'})
+@jsii.data_type(jsii_type="@aws-cdk/aws-kms.AliasProps", jsii_struct_bases=[], name_mapping={'alias_name': 'aliasName', 'target_key': 'targetKey', 'removal_policy': 'removalPolicy'})
 class AliasProps():
-    def __init__(self, *, alias_name: str, target_key: "IKey"):
+    def __init__(self, *, alias_name: str, target_key: "IKey", removal_policy: typing.Optional[aws_cdk.core.RemovalPolicy]=None):
         """Construction properties for a KMS Key Alias object.
 
         :param alias_name: The name of the alias. The name must start with alias followed by a forward slash, such as alias/. You can't specify aliases that begin with alias/AWS. These aliases are reserved.
         :param target_key: The ID of the key for which you are creating the alias. Specify the key's globally unique identifier or Amazon Resource Name (ARN). You can't specify another alias.
+        :param removal_policy: Policy to apply when the alias is removed from this stack. Default: - The alias will be deleted
         """
         self._values = {
             'alias_name': alias_name,
             'target_key': target_key,
         }
+        if removal_policy is not None: self._values["removal_policy"] = removal_policy
 
     @property
     def alias_name(self) -> str:
@@ -75,6 +77,15 @@ class AliasProps():
         """
         return self._values.get('target_key')
 
+    @property
+    def removal_policy(self) -> typing.Optional[aws_cdk.core.RemovalPolicy]:
+        """Policy to apply when the alias is removed from this stack.
+
+        default
+        :default: - The alias will be deleted
+        """
+        return self._values.get('removal_policy')
+
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -444,111 +455,6 @@ class CfnKeyProps():
         return 'CfnKeyProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
-@jsii.interface(jsii_type="@aws-cdk/aws-kms.IAlias")
-class IAlias(aws_cdk.core.IResource, jsii.compat.Protocol):
-    """A KMS Key alias."""
-    @staticmethod
-    def __jsii_proxy_class__():
-        return _IAliasProxy
-
-    @property
-    @jsii.member(jsii_name="aliasName")
-    def alias_name(self) -> str:
-        """The name of the alias.
-
-        attribute:
-        :attribute:: true
-        """
-        ...
-
-    @property
-    @jsii.member(jsii_name="aliasTargetKey")
-    def alias_target_key(self) -> "IKey":
-        """The Key to which the Alias refers.
-
-        attribute:
-        :attribute:: true
-        """
-        ...
-
-
-class _IAliasProxy(jsii.proxy_for(aws_cdk.core.IResource)):
-    """A KMS Key alias."""
-    __jsii_type__ = "@aws-cdk/aws-kms.IAlias"
-    @property
-    @jsii.member(jsii_name="aliasName")
-    def alias_name(self) -> str:
-        """The name of the alias.
-
-        attribute:
-        :attribute:: true
-        """
-        return jsii.get(self, "aliasName")
-
-    @property
-    @jsii.member(jsii_name="aliasTargetKey")
-    def alias_target_key(self) -> "IKey":
-        """The Key to which the Alias refers.
-
-        attribute:
-        :attribute:: true
-        """
-        return jsii.get(self, "aliasTargetKey")
-
-
-@jsii.implements(IAlias)
-class Alias(aws_cdk.core.Resource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.Alias"):
-    """Defines a display name for a customer master key (CMK) in AWS Key Management Service (AWS KMS).
-
-    Using an alias to refer to a key can help you simplify key
-    management. For example, when rotating keys, you can just update the alias
-    mapping instead of tracking and changing key IDs. For more information, see
-    Working with Aliases in the AWS Key Management Service Developer Guide.
-
-    You can also add an alias for a key by calling ``key.addAlias(alias)``.
-
-    resource:
-    :resource:: AWS::KMS::Alias
-    """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, alias_name: str, target_key: "IKey") -> None:
-        """
-        :param scope: -
-        :param id: -
-        :param props: -
-        :param alias_name: The name of the alias. The name must start with alias followed by a forward slash, such as alias/. You can't specify aliases that begin with alias/AWS. These aliases are reserved.
-        :param target_key: The ID of the key for which you are creating the alias. Specify the key's globally unique identifier or Amazon Resource Name (ARN). You can't specify another alias.
-        """
-        props = AliasProps(alias_name=alias_name, target_key=target_key)
-
-        jsii.create(Alias, self, [scope, id, props])
-
-    @jsii.member(jsii_name="fromAliasAttributes")
-    @classmethod
-    def from_alias_attributes(cls, scope: aws_cdk.core.Construct, id: str, *, alias_name: str, alias_target_key: "IKey") -> "IAlias":
-        """
-        :param scope: -
-        :param id: -
-        :param attrs: -
-        :param alias_name: 
-        :param alias_target_key: 
-        """
-        attrs = AliasAttributes(alias_name=alias_name, alias_target_key=alias_target_key)
-
-        return jsii.sinvoke(cls, "fromAliasAttributes", [scope, id, attrs])
-
-    @property
-    @jsii.member(jsii_name="aliasName")
-    def alias_name(self) -> str:
-        """The name of the alias."""
-        return jsii.get(self, "aliasName")
-
-    @property
-    @jsii.member(jsii_name="aliasTargetKey")
-    def alias_target_key(self) -> "IKey":
-        """The Key to which the Alias refers."""
-        return jsii.get(self, "aliasTargetKey")
-
-
 @jsii.interface(jsii_type="@aws-cdk/aws-kms.IKey")
 class IKey(aws_cdk.core.IResource, jsii.compat.Protocol):
     """A KMS Key, either managed by this CDK app, or imported."""
@@ -566,6 +472,16 @@ class IKey(aws_cdk.core.IResource, jsii.compat.Protocol):
         """
         ...
 
+    @property
+    @jsii.member(jsii_name="keyId")
+    def key_id(self) -> str:
+        """The ID of the key (the part that looks something like: 1234abcd-12ab-34cd-56ef-1234567890ab).
+
+        attribute:
+        :attribute:: true
+        """
+        ...
+
     @jsii.member(jsii_name="addAlias")
     def add_alias(self, alias: str) -> "Alias":
         """Defines a new alias for the key.
@@ -630,6 +546,16 @@ class _IKeyProxy(jsii.proxy_for(aws_cdk.core.IResource)):
         """
         return jsii.get(self, "keyArn")
 
+    @property
+    @jsii.member(jsii_name="keyId")
+    def key_id(self) -> str:
+        """The ID of the key (the part that looks something like: 1234abcd-12ab-34cd-56ef-1234567890ab).
+
+        attribute:
+        :attribute:: true
+        """
+        return jsii.get(self, "keyId")
+
     @jsii.member(jsii_name="addAlias")
     def add_alias(self, alias: str) -> "Alias":
         """Defines a new alias for the key.
@@ -681,6 +607,178 @@ class _IKeyProxy(jsii.proxy_for(aws_cdk.core.IResource)):
         return jsii.invoke(self, "grantEncryptDecrypt", [grantee])
 
 
+@jsii.interface(jsii_type="@aws-cdk/aws-kms.IAlias")
+class IAlias(IKey, jsii.compat.Protocol):
+    """A KMS Key alias. An alias can be used in all places that expect a key."""
+    @staticmethod
+    def __jsii_proxy_class__():
+        return _IAliasProxy
+
+    @property
+    @jsii.member(jsii_name="aliasName")
+    def alias_name(self) -> str:
+        """The name of the alias.
+
+        attribute:
+        :attribute:: true
+        """
+        ...
+
+    @property
+    @jsii.member(jsii_name="aliasTargetKey")
+    def alias_target_key(self) -> "IKey":
+        """The Key to which the Alias refers.
+
+        attribute:
+        :attribute:: true
+        """
+        ...
+
+
+class _IAliasProxy(jsii.proxy_for(IKey)):
+    """A KMS Key alias. An alias can be used in all places that expect a key."""
+    __jsii_type__ = "@aws-cdk/aws-kms.IAlias"
+    @property
+    @jsii.member(jsii_name="aliasName")
+    def alias_name(self) -> str:
+        """The name of the alias.
+
+        attribute:
+        :attribute:: true
+        """
+        return jsii.get(self, "aliasName")
+
+    @property
+    @jsii.member(jsii_name="aliasTargetKey")
+    def alias_target_key(self) -> "IKey":
+        """The Key to which the Alias refers.
+
+        attribute:
+        :attribute:: true
+        """
+        return jsii.get(self, "aliasTargetKey")
+
+
+@jsii.implements(IAlias)
+class Alias(aws_cdk.core.Resource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.Alias"):
+    """Defines a display name for a customer master key (CMK) in AWS Key Management Service (AWS KMS).
+
+    Using an alias to refer to a key can help you simplify key
+    management. For example, when rotating keys, you can just update the alias
+    mapping instead of tracking and changing key IDs. For more information, see
+    Working with Aliases in the AWS Key Management Service Developer Guide.
+
+    You can also add an alias for a key by calling ``key.addAlias(alias)``.
+
+    resource:
+    :resource:: AWS::KMS::Alias
+    """
+    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, alias_name: str, target_key: "IKey", removal_policy: typing.Optional[aws_cdk.core.RemovalPolicy]=None) -> None:
+        """
+        :param scope: -
+        :param id: -
+        :param props: -
+        :param alias_name: The name of the alias. The name must start with alias followed by a forward slash, such as alias/. You can't specify aliases that begin with alias/AWS. These aliases are reserved.
+        :param target_key: The ID of the key for which you are creating the alias. Specify the key's globally unique identifier or Amazon Resource Name (ARN). You can't specify another alias.
+        :param removal_policy: Policy to apply when the alias is removed from this stack. Default: - The alias will be deleted
+        """
+        props = AliasProps(alias_name=alias_name, target_key=target_key, removal_policy=removal_policy)
+
+        jsii.create(Alias, self, [scope, id, props])
+
+    @jsii.member(jsii_name="fromAliasAttributes")
+    @classmethod
+    def from_alias_attributes(cls, scope: aws_cdk.core.Construct, id: str, *, alias_name: str, alias_target_key: "IKey") -> "IAlias":
+        """
+        :param scope: -
+        :param id: -
+        :param attrs: -
+        :param alias_name: 
+        :param alias_target_key: 
+        """
+        attrs = AliasAttributes(alias_name=alias_name, alias_target_key=alias_target_key)
+
+        return jsii.sinvoke(cls, "fromAliasAttributes", [scope, id, attrs])
+
+    @jsii.member(jsii_name="addAlias")
+    def add_alias(self, alias: str) -> "Alias":
+        """Defines a new alias for the key.
+
+        :param alias: -
+        """
+        return jsii.invoke(self, "addAlias", [alias])
+
+    @jsii.member(jsii_name="addToResourcePolicy")
+    def add_to_resource_policy(self, statement: aws_cdk.aws_iam.PolicyStatement, allow_no_op: typing.Optional[bool]=None) -> None:
+        """Adds a statement to the KMS key resource policy.
+
+        :param statement: -
+        :param allow_no_op: -
+        """
+        return jsii.invoke(self, "addToResourcePolicy", [statement, allow_no_op])
+
+    @jsii.member(jsii_name="generatePhysicalName")
+    def _generate_physical_name(self) -> str:
+        return jsii.invoke(self, "generatePhysicalName", [])
+
+    @jsii.member(jsii_name="grant")
+    def grant(self, grantee: aws_cdk.aws_iam.IGrantable, *actions: str) -> aws_cdk.aws_iam.Grant:
+        """Grant the indicated permissions on this key to the given principal.
+
+        :param grantee: -
+        :param actions: -
+        """
+        return jsii.invoke(self, "grant", [grantee, *actions])
+
+    @jsii.member(jsii_name="grantDecrypt")
+    def grant_decrypt(self, grantee: aws_cdk.aws_iam.IGrantable) -> aws_cdk.aws_iam.Grant:
+        """Grant decryption permisisons using this key to the given principal.
+
+        :param grantee: -
+        """
+        return jsii.invoke(self, "grantDecrypt", [grantee])
+
+    @jsii.member(jsii_name="grantEncrypt")
+    def grant_encrypt(self, grantee: aws_cdk.aws_iam.IGrantable) -> aws_cdk.aws_iam.Grant:
+        """Grant encryption permisisons using this key to the given principal.
+
+        :param grantee: -
+        """
+        return jsii.invoke(self, "grantEncrypt", [grantee])
+
+    @jsii.member(jsii_name="grantEncryptDecrypt")
+    def grant_encrypt_decrypt(self, grantee: aws_cdk.aws_iam.IGrantable) -> aws_cdk.aws_iam.Grant:
+        """Grant encryption and decryption permisisons using this key to the given principal.
+
+        :param grantee: -
+        """
+        return jsii.invoke(self, "grantEncryptDecrypt", [grantee])
+
+    @property
+    @jsii.member(jsii_name="aliasName")
+    def alias_name(self) -> str:
+        """The name of the alias."""
+        return jsii.get(self, "aliasName")
+
+    @property
+    @jsii.member(jsii_name="aliasTargetKey")
+    def alias_target_key(self) -> "IKey":
+        """The Key to which the Alias refers."""
+        return jsii.get(self, "aliasTargetKey")
+
+    @property
+    @jsii.member(jsii_name="keyArn")
+    def key_arn(self) -> str:
+        """The ARN of the key."""
+        return jsii.get(self, "keyArn")
+
+    @property
+    @jsii.member(jsii_name="keyId")
+    def key_id(self) -> str:
+        """The ID of the key (the part that looks something like: 1234abcd-12ab-34cd-56ef-1234567890ab)."""
+        return jsii.get(self, "keyId")
+
+
 @jsii.implements(IKey)
 class Key(aws_cdk.core.Resource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.Key"):
     """Defines a KMS key.
@@ -775,6 +873,12 @@ class Key(aws_cdk.core.Resource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aw
         """The ARN of the key."""
         return jsii.get(self, "keyArn")
 
+    @property
+    @jsii.member(jsii_name="keyId")
+    def key_id(self) -> str:
+        """The ID of the key (the part that looks something like: 1234abcd-12ab-34cd-56ef-1234567890ab)."""
+        return jsii.get(self, "keyId")
+
     @property
     @jsii.member(jsii_name="policy")
     def _policy(self) -> typing.Optional[aws_cdk.aws_iam.PolicyDocument]:
